<?php

/**
 * @file
 * Default theme implementation to display an iCal calendar.
 *
 * Available variables:
 * @var string $title  The name of the calendar.
 * @var string $prodId  The product name of the exporting system.
 * @var string $langcode  The ISO 3166 2 character language code defining the
 *   language used n the feed.
 * @var string $method  The action to perform for the event (PUBLISH or CANCEL).
 * @var \stdClass[] $events  An array of unavailable periods.
 *
 * If you are editing this file, remember that all output lines generated by it
 * must end with Windows-style \r\n line endings, and not Unix-style \n, in
 * order to be compliant with the iCal spec.
 * @see http://tools.ietf.org/html/rfc5545#section-3.1
 *
 * @ingroup themeable
 */
$eol = "\r\n";

print "BEGIN:VCALENDAR$eol";
print "VERSION:2.0$eol";
print "CALSCALE:GREGORIAN$eol";
print "METHOD:$method$eol";
if (!empty($title)):
  print "X-WR-CALNAME;VALUE=TEXT:$title$eol";
endif;
print "PRODID:-//$prodId//$langcode$eol";

foreach($events as $event):
  /** @noinspection PhpUnhandledExceptionInspection */
  print theme('availability_calendar_ical_vevent', array(
    'start' => $event->start,
    'end' => $event->end,
    'uid' => isset($event->uid) ? $event->uid : '',
    'summary' => isset($event->summary) ? $event->summary : '',
    'title' => $title,
    'langcode' => $langcode,
  ));
endforeach;

print "END:VCALENDAR\r\n";
